@@ -131,15 +131,14 @@ impl<K: PageNo, const NBYTES: usize> Pages<K, NBYTES> {
         }
     }
 
-    /// Increase page number by `count`, and return the new length.
+    /// Increase page number by `count`
     pub async fn alloc(&self, count: u32) -> Result<u32> {
         let old_len = self.len.fetch_add(count, Ordering::SeqCst);
-        let new_len = old_len + count;
         let file = self.file;
         unsafe {
             spawn_blocking(move || {
-                file.set_len(NBYTES as u64 * new_len as u64)?;
-                Ok(new_len)
+                file.set_len(NBYTES as u64 * (old_len + count) as u64)?;
+                Ok(old_len)
             })
             .await
             .unwrap_unchecked()
